#!/usr/bin/env node
'use strict';

var _promise = require('./promise');

var validate = _interopRequireWildcard(_promise);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _error = require('./error');

var _error2 = _interopRequireDefault(_error);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

_commander2.default.usage('[options] <files...>').option('-s, --schema [name]', 'validate schema name (log, request, response, etc ...)').parse(process.argv);

if (!_commander2.default.args.length) {
  _commander2.default.help();
}

var schema = _commander2.default.schema || 'har';

_commander2.default.args.map(function (fileName) {
  var file = _chalk2.default.yellow.italic(_path2.default.basename(fileName));

  new Promise(function (resolve, reject) {
    _fs2.default.readFile(fileName, function (err, data) {
      return err === null ? resolve(data) : reject(err);
    });
  }).then(JSON.parse).then(validate[schema]).then(function (data) {
    return console.log('%s [%s] is a valid %s', _chalk2.default.green('✓'), file, _chalk2.default.magenta(schema));
  }).catch(function (err) {
    console.error('[%s]', file);

    if (err instanceof SyntaxError) {
      return console.error('%s failed to read JSON: %s', _chalk2.default.red('✖'), _chalk2.default.red(err.message));
    }

    if (err instanceof _error2.default) {
      err.errors.forEach(function (details) {
        return console.error('%s validation failed on %s: %s', _chalk2.default.red('✖'), _chalk2.default.cyan.italic(details.dataPath || '.'), _chalk2.default.red(details.message));
      });
      return;
    }

    console.error('%s an unknown error has occured: %s', _chalk2.default.red('✖'), _chalk2.default.red(err.message));
  });
});