'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validator = validator;
exports.har = har;
exports.cache = cache;
exports.cacheEntry = cacheEntry;
exports.content = content;
exports.cookie = cookie;
exports.creator = creator;
exports.browser = browser;
exports.entry = entry;
exports.log = log;
exports.page = page;
exports.pageTimings = pageTimings;
exports.postData = postData;
exports.query = query;
exports.header = header;
exports.request = request;
exports.response = response;
exports.timings = timings;

var _harSchema = require('har-schema');

var schemas = _interopRequireWildcard(_harSchema);

var _ajv = require('ajv');

var _ajv2 = _interopRequireDefault(_ajv);

var _error = require('./error');

var _error2 = _interopRequireDefault(_error);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function validator(schema, data = {}, cb) {
  // default value
  let valid = false;

  // validator config
  let ajv = new _ajv2.default({
    allErrors: true,
    schemas: schemas
  });

  let validate = ajv.compile(schema);

  // execute validation
  valid = validate(data);

  // callback?
  if (typeof cb === 'function') {
    return cb(validate.errors ? new _error2.default(validate.errors) : null, valid);
  }

  return valid;
}

function har(data, cb) {
  return validator(schemas.har, data, cb);
}

function cache(data, cb) {
  return validator(schemas.cache, data, cb);
}

function cacheEntry(data, cb) {
  return validator(schemas.cacheEntry, data, cb);
}

function content(data, cb) {
  return validator(schemas.content, data, cb);
}

function cookie(data, cb) {
  return validator(schemas.cookie, data, cb);
}

function creator(data, cb) {
  return validator(schemas.creator, data, cb);
}

function browser(data, cb) {
  return validator(schemas.browser, data, cb);
}

function entry(data, cb) {
  return validator(schemas.entry, data, cb);
}

function log(data, cb) {
  return validator(schemas.log, data, cb);
}

function page(data, cb) {
  return validator(schemas.page, data, cb);
}

function pageTimings(data, cb) {
  return validator(schemas.pageTimings, data, cb);
}

function postData(data, cb) {
  return validator(schemas.postData, data, cb);
}

function query(data, cb) {
  return validator(schemas.record, data, cb);
}

function header(data, cb) {
  return validator(schemas.record, data, cb);
}

function request(data, cb) {
  return validator(schemas.request, data, cb);
}

function response(data, cb) {
  return validator(schemas.response, data, cb);
}

function timings(data, cb) {
  return validator(schemas.timings, data, cb);
}